@@ -18,10 +18,11 @@
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KCursor>
+#include <KLineEditUrlDropEventFilter>
 #include <KSharedConfig>
 #include <KStandardShortcut>
+
 #include <kcompletionbox.h>
-#include <lineediturldropeventfilter.h>
 
 #include <QActionGroup>
 #include <QApplication>
@@ -43,9 +44,6 @@ void KLineEditPrivate::_k_textChanged(const QString &text)
     // COMPAT (as documented): emit userTextChanged whenever textChanged is emitted
     if (!completionRunning && (text != userText)) {
         userText = text;
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-        Q_EMIT q->userTextChanged(text);
-#endif
     }
 }
 
@@ -57,9 +55,6 @@ void KLineEditPrivate::updateUserText(const QString &text)
     if (!completionRunning && (text != userText)) {
         userText = text;
         q->setModified(true);
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-        Q_EMIT q->userTextChanged(text);
-#endif
         Q_EMIT q->textEdited(text);
         Q_EMIT q->textChanged(text);
     }
@@ -83,12 +78,12 @@ void KLineEditPrivate::init()
 
     completionRunning = false;
     if (!s_initialized) {
-        KConfigGroup config(KSharedConfig::openConfig(), "General");
+        KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
         s_backspacePerformsCompletion = config.readEntry("Backspace performs completion", false);
         s_initialized = true;
     }
 
-    urlDropEventFilter = new LineEditUrlDropEventFilter(q);
+    urlDropEventFilter = new KLineEditUrlDropEventFilter(q);
 
     // i18n: Placeholder text in line edit widgets is the text appearing
     // before any user input, briefly explaining to the user what to type
@@ -150,27 +145,6 @@ KLineEdit::~KLineEdit()
 {
 }
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
-QString KLineEdit::clickMessage() const
-{
-    return placeholderText();
-}
-#endif
-
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 46)
-void KLineEdit::setClearButtonShown(bool show)
-{
-    setClearButtonEnabled(show);
-}
-#endif
-
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 46)
-bool KLineEdit::isClearButtonShown() const
-{
-    return isClearButtonEnabled();
-}
-#endif
-
 QSize KLineEdit::clearButtonUsedSize() const
 {
     QSize s;
@@ -295,7 +269,7 @@ void KLineEdit::makeCompletion(const QString &text)
                 d->completionBox->clear();
             }
         } else {
-            setCompletedItems(comp->allMatches());
+            setCompletedItems(comp->allMatches(), comp->shouldAutoSuggest());
         }
     } else { // Auto,  ShortAuto (Man) and Shell
         // all other completion modes
@@ -384,6 +358,7 @@ void KLineEditPrivate::setSqueezedText()
 
     // TODO: investigate use of QFontMetrics::elidedText for this
     if (textWidth > labelWidth) {
+        const QStringView sview{fullText};
         // TODO: better would be "…" char (0x2026), but for that one would need to ensure it's from the main font,
         // otherwise if resulting in use of a new fallback font this can affect the metrics of the complete text,
         // resulting in shifted characters
@@ -394,7 +369,7 @@ void KLineEditPrivate::setSqueezedText()
 
         // estimate how many letters we can add to the dots on both sides
         int letters = fullText.length() * (labelWidth - squeezedWidth) / textWidth / 2;
-        squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+        squeezedText = sview.left(letters) + ellipsisText + sview.right(letters);
         squeezedWidth = fm.boundingRect(squeezedText).width();
 
         if (squeezedWidth < labelWidth) {
@@ -402,17 +377,17 @@ void KLineEditPrivate::setSqueezedText()
             // add letters while text < label
             do {
                 letters++;
-                squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+                squeezedText = sview.left(letters) + ellipsisText + sview.right(letters);
                 squeezedWidth = fm.boundingRect(squeezedText).width();
             } while (squeezedWidth < labelWidth && letters <= fullLength / 2);
             letters--;
-            squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+            squeezedText = sview.left(letters) + ellipsisText + sview.right(letters);
         } else if (squeezedWidth > labelWidth) {
             // we estimated too long
             // remove letters while text > label
             do {
                 letters--;
-                squeezedText = fullText.leftRef(letters) + ellipsisText + fullText.rightRef(letters);
+                squeezedText = sview.left(letters) + ellipsisText + sview.right(letters);
                 squeezedWidth = fm.boundingRect(squeezedText).width();
             } while (squeezedWidth > labelWidth && letters >= 5);
         }
@@ -454,7 +429,8 @@ bool KLineEditPrivate::copySqueezedText(bool copy) const
         if (!that->hasSelectedText()) {
             return false;
         }
-        int start = q->selectionStart(), end = start + q->selectedText().length();
+        int start = q->selectionStart();
+        int end = start + q->selectedText().length();
         if (start >= squeezedStart + 3) {
             start = start - 3 - squeezedStart + squeezedEnd;
         } else if (start > squeezedStart) {
@@ -571,9 +547,6 @@ void KLineEdit::keyPressEvent(QKeyEvent *e)
                 Q_EMIT QLineEdit::returnPressed();
                 e->accept();
             }
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
-            Q_EMIT returnPressed(displayText());
-#endif
             Q_EMIT returnKeyPressed(displayText());
             if (trap) {
                 d->completionBox->hide();
@@ -1077,20 +1050,6 @@ bool KLineEdit::event(QEvent *ev)
     return QLineEdit::event(ev);
 }
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
-void KLineEdit::setUrlDropsEnabled(bool enable)
-{
-    Q_D(KLineEdit);
-    if (enable && !d->handleURLDrops) {
-        installEventFilter(d->urlDropEventFilter);
-        d->handleURLDrops = true;
-    } else if (!enable && d->handleURLDrops) {
-        removeEventFilter(d->urlDropEventFilter);
-        d->handleURLDrops = false;
-    }
-}
-#endif
-
 bool KLineEdit::urlDropsEnabled() const
 {
     Q_D(const KLineEdit);
@@ -1129,13 +1088,8 @@ void KLineEdit::setCompletionBox(KCompletionBox *box)
 
         connect(d->completionBox, &KCompletionBox::userCancelled, this, &KLineEdit::userCancelled);
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
-        connect(d->completionBox, QOverload<const QString &>::of(&KCompletionBox::activated), this, &KLineEdit::completionBoxActivated);
-        connect(d->completionBox, QOverload<const QString &>::of(&KCompletionBox::activated), this, &KLineEdit::textEdited);
-#else
         connect(d->completionBox, &KCompletionBox::textActivated, this, &KLineEdit::completionBoxActivated);
         connect(d->completionBox, &KCompletionBox::textActivated, this, &KLineEdit::textEdited);
-#endif
     }
 }
 
@@ -1211,6 +1165,9 @@ bool KLineEditPrivate::overrideShortcut(const QKeyEvent *e)
         return true;
     }
 
+    constexpr int ctrlE = QKeyCombination(Qt::CTRL | Qt::Key_E).toCombined();
+    constexpr int ctrlU = QKeyCombination(Qt::CTRL | Qt::Key_U).toCombined();
+
     // Override all the text manupilation accelerators...
     if (KStandardShortcut::copy().contains(key)) {
         return true;
@@ -1240,7 +1197,7 @@ bool KLineEditPrivate::overrideShortcut(const QKeyEvent *e)
     // but doesn't dare force as "stronger than kaction shortcuts"...
     else if (e->matches(QKeySequence::SelectAll)) {
         return true;
-    } else if (qApp->platformName() == QLatin1String("xcb") && (key == (Qt::CTRL | Qt::Key_E) || key == (Qt::CTRL | Qt::Key_U))) {
+    } else if (qApp->platformName() == QLatin1String("xcb") && (key == ctrlE || key == ctrlU)) {
         return true;
     }
 
@@ -1328,12 +1285,18 @@ KCompletionBox *KLineEdit::completionBox(bool create)
 
 void KLineEdit::setCompletionObject(KCompletion *comp, bool handle)
 {
-    KCompletion *oldComp = compObj();
-    if (oldComp && handleSignals())
-        disconnect(oldComp, SIGNAL(matches(QStringList)), this, SLOT(setCompletedItems(QStringList)));
+    Q_D(class KLineEdit);
 
-    if (comp && handle)
-        connect(comp, SIGNAL(matches(QStringList)), this, SLOT(setCompletedItems(QStringList)));
+    KCompletion *oldComp = compObj();
+    if (oldComp && handleSignals()) {
+        disconnect(d->m_matchesConnection);
+    }
+
+    if (comp && handle) {
+        d->m_matchesConnection = connect(comp, &KCompletion::matches, this, [this](const QStringList &list) {
+            setCompletedItems(list);
+        });
+    }
 
     KCompletionBase::setCompletionObject(comp, handle);
 }
@@ -1433,49 +1396,6 @@ void KLineEdit::paintEvent(QPaintEvent *ev)
     }
 }
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
-void KLineEdit::setClickMessage(const QString &msg)
-{
-    setPlaceholderText(msg);
-}
-#endif
-
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-void KLineEdit::setContextMenuEnabled(bool showMenu)
-{
-    QLineEdit::setContextMenuPolicy(showMenu ? Qt::DefaultContextMenu : Qt::NoContextMenu);
-}
-#endif
-
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-bool KLineEdit::isContextMenuEnabled() const
-{
-    return (contextMenuPolicy() == Qt::DefaultContextMenu);
-}
-#endif
-
-void KLineEdit::setPasswordMode(bool passwordMode)
-{
-    Q_D(KLineEdit);
-    if (passwordMode) {
-        KConfigGroup cg(KSharedConfig::openConfig(), "Passwords");
-        const QString val = cg.readEntry("EchoMode", "OneStar");
-        if (val == QLatin1String("NoEcho")) {
-            setEchoMode(NoEcho);
-        } else {
-            d->threeStars = (val == QLatin1String("ThreeStars"));
-            setEchoMode(Password);
-        }
-    } else {
-        setEchoMode(Normal);
-    }
-}
-
-bool KLineEdit::passwordMode() const
-{
-    return echoMode() == NoEcho || echoMode() == Password;
-}
-
 void KLineEdit::doCompletion(const QString &text)
 {
     Q_D(KLineEdit);
