@@ -18,8 +18,8 @@
 #define KLINEEDIT_H
 
 #include <kcompletion.h>
-#include <kcompletionbase.h>
 #include <kcompletion_export.h>
+#include <kcompletionbase.h>
 
 #include <QLineEdit>
 #include <memory>
@@ -38,131 +38,114 @@ class KLineEditPrivate;
  * \b Detail \n
  *
  * This widget inherits from QLineEdit and implements the following
- * additional functionalities: a completion object that provides both
- * automatic and manual text completion as well as multiple match iteration
- * features, configurable key-bindings to activate these features and a
- * popup-menu item that can be used to allow the user to set text completion
- * modes on the fly based on their preference.
+ * additional functionalities:
+ * @li a completion object that provides both automatic and manual text
+ * completion as well as multiple match iteration features
+ * @li configurable key-bindings to activate these features
+ * @li a popup-menu item that can be used to allow the user to set text
+ * completion modes on the fly based on their preference
  *
- * To support these new features KLineEdit also emits a few more
- * additional signals. These are: completion( const QString& ),
- * textRotation( KeyBindingType ), and returnPressed( const QString& ).
- * The completion signal can be connected to a slot that will assist the
- * user in filling out the remaining text. The text rotation signal is
- * intended to be used to iterate through the list of all possible matches
- * whenever there is more than one match for the entered text. The
- * @c returnPressed( const QString& ) signals are the same as QLineEdit's
- * except it provides the current text in the widget as its argument whenever
- * appropriate.
+ * To support these features KLineEdit also emits a few more additional
+ * signals:
+ * @li @c completion(const QString &): this signal can be connected to
+ * a slot that will assist the user in filling out the remaining text
+ * @li @c textRotation(KeyBindingType): this signal is intended to be
+ * used to iterate through the list of all possible matches whenever
+ * there is more than one match for the entered text
+ * @li @c returnKeyPressed(const QString &): this signal provides the
+ * current text in the widget as its argument whenever appropriate (this
+ * is in addition to the @c QLineEdit::returnPressed() signal which KLineEdit
+ * inherits from QLineEdit).
  *
  * This widget by default creates a completion object when you invoke
- * the completionObject( bool ) member function for the first time or
- * use setCompletionObject( KCompletion*, bool ) to assign your own
+ * the @c completionObject(bool) member function for the first time or
+ * use @c setCompletionObject(KCompletion *, bool) to assign your own
  * completion object. Additionally, to make this widget more functional,
  * KLineEdit will by default handle the text rotation and completion
  * events internally when a completion object is created through either one
  * of the methods mentioned above. If you do not need this functionality,
- * simply use KCompletionBase::setHandleSignals( bool ) or set the
- * boolean parameter in the above functions to false.
+ * simply use @c KCompletionBase::setHandleSignals(bool) or set the boolean
+ * parameter in the above functions to false.
  *
  * The default key-bindings for completion and rotation is determined
  * from the global settings in KStandardShortcut. These values, however,
- * can be overridden locally by invoking KCompletionBase::setKeyBinding().
+ * can be overridden locally by invoking @c KCompletionBase::setKeyBinding().
  * The values can easily be reverted back to the default setting, by simply
- * calling useGlobalSettings(). An alternate method would be to default
+ * calling @c useGlobalSettings(). An alternate method would be to default
  * individual key-bindings by using setKeyBinding() with the default
  * second argument.
  *
  * If @c EchoMode for this widget is set to something other than @c QLineEdit::Normal,
  * the completion mode will always be defaulted to CompletionNone.
- * This is done purposefully to guard against protected entries such as passwords being
- * cached in KCompletion's list. Hence, if the @c EchoMode is not QLineEdit::Normal, the
- * completion mode is automatically disabled.
+ * This is done purposefully to guard against protected entries, such as
+ * passwords, being cached in KCompletion's list. Hence, if the @c EchoMode
+ * is not @c QLineEdit::Normal, the completion mode is automatically disabled.
  *
- * A read-only KLineEdit will have the same background color as a
- * disabled KLineEdit, but its foreground color will be the one used
- * for the read-write mode. This differs from QLineEdit's implementation
- * and is done to give visual distinction between the three different modes:
- * disabled, read-only, and read-write.
+ * A read-only KLineEdit will have the same background color as a disabled
+ * KLineEdit, but its foreground color will be the one used for the read-write
+ * mode. This differs from QLineEdit's implementation and is done to give visual
+ * distinction between the three different modes: disabled, read-only, and read-write.
  *
- * KLineEdit has also a password mode which depends of globals KDE settings. Use
- * KLineEdit::setPasswordMode instead of QLineEdit::echoMode property to have a password field.
- *
- * \b Usage \n
+ * @b Usage
  *
  * To enable the basic completion feature:
  *
- * \code
- * KLineEdit *edit = new KLineEdit( this );
+ * @code
+ * KLineEdit *edit = new KLineEdit(this);
  * KCompletion *comp = edit->completionObject();
- * // Connect to the return pressed signal - optional
- * connect(edit,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&)));
- * \endcode
+ * // Connect to the Return pressed signal - optional
+ * connect(edit, &KLineEdit::returnKeyPressed, comp, [this](const QString &text) { addItem(text); });
+ * @endcode
  *
- * To use a customized completion objects or your
- * own completion object:
+ * To use a customized completion object or your own completion object:
  *
- * \code
- * KLineEdit *edit = new KLineEdit( this );
+ * @code
+ * KLineEdit *edit = new KLineEdit(this);
  * KUrlCompletion *comp = new KUrlCompletion();
- * edit->setCompletionObject( comp );
+ * edit->setCompletionObject(comp);
  * // Connect to the return pressed signal - optional
- * connect(edit,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&)));
- * \endcode
+ * connect(edit, &KLineEdit::returnKeyPressed, comp, [this](const QString &text) { addItem(text); });
+ * @endcode
  *
  * Note if you specify your own completion object you have to either delete
  * it when you don't need it anymore, or you can tell KLineEdit to delete it
  * for you:
- * \code
- * edit->setAutoDeleteCompletionObject( true );
- * \endcode
+ * @code
+ * edit->setAutoDeleteCompletionObject(true);
+ * @endcode
  *
  * <b>Miscellaneous function calls :</b>\n
  *
- * \code
- * // Tell the widget to not handle completion and iteration automatically.
- * edit->setHandleSignals( false );
+ * @code
+ * // Tell the widget to not handle completion and iteration automatically
+ * edit->setHandleSignals(false);
  *
- * // Set your own key-bindings for a text completion mode.
- * edit->setKeyBinding( KCompletionBase::TextCompletion, Qt::End );
+ * // Set your own key-bindings for a text completion mode
+ * edit->setKeyBinding(KCompletionBase::TextCompletion, Qt::End);
  *
  * // Hide the context (popup) menu
- * edit->setContextMenuPolicy( Qt::NoContextMenu );
+ * edit->setContextMenuPolicy(Qt::NoContextMenu);
  *
- * // Default the key-bindings back to the default system settings.
+ * // Default the key-bindings back to the default system settings
  * edit->useGlobalKeyBindings();
- * \endcode
+ * @endcode
  *
- * \image html klineedit.png "KLineEdit widgets with clear-button"
+ * @image html klineedit.png "KLineEdit widgets with clear-button"
  *
  * @author Dawit Alemayehu <adawit@kde.org>
  */
 
-class KCOMPLETION_EXPORT KLineEdit : public QLineEdit, public KCompletionBase //krazy:exclude=qclasses
+class KCOMPLETION_EXPORT KLineEdit : public QLineEdit, public KCompletionBase // krazy:exclude=qclasses
 {
     friend class KComboBox;
     friend class KLineEditStyle;
 
     Q_OBJECT
     Q_DECLARE_PRIVATE(KLineEdit)
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-    Q_PROPERTY(bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled)
-#endif
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
-    Q_PROPERTY(bool urlDropsEnabled READ urlDropsEnabled WRITE setUrlDropsEnabled)
-#endif
     Q_PROPERTY(bool trapEnterKeyEvent READ trapReturnKey WRITE setTrapReturnKey)
     Q_PROPERTY(bool squeezedTextEnabled READ isSqueezedTextEnabled WRITE setSqueezedTextEnabled)
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
-    Q_PROPERTY(QString clickMessage READ clickMessage WRITE setClickMessage)
-#endif
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 46)
-    Q_PROPERTY(bool showClearButton READ isClearButtonShown WRITE setClearButtonShown)
-#endif
-    Q_PROPERTY(bool passwordMode READ passwordMode WRITE setPasswordMode)
 
 public:
-
     /**
      * Constructs a KLineEdit object with a default text, a parent,
      * and a name.
@@ -190,51 +173,23 @@ public:
     void setUrl(const QUrl &url);
 
     /**
-    * Reimplemented from KCompletionBase for internal reasons.
-    *
-    * This function is re-implemented in order to make sure that
-    * the EchoMode is acceptable before we set the completion mode.
-    *
-    * See KCompletionBase::setCompletionMode
-    */
+     * Reimplemented from KCompletionBase for internal reasons.
+     *
+     * This function is re-implemented in order to make sure that
+     * the EchoMode is acceptable before we set the completion mode.
+     *
+     * See KCompletionBase::setCompletionMode
+     */
     void setCompletionMode(KCompletion::CompletionMode mode) override;
 
     /**
-     * Disables completion modes by makeing them non-checkable.
+     * Disables completion modes by making them non-checkable.
      *
      * The context menu allows to change the completion mode.
      * This method allows to disable some modes.
      */
     void setCompletionModeDisabled(KCompletion::CompletionMode mode, bool disable = true);
 
-#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
-    /**
-     * Enables/disables the popup (context) menu.
-     *
-     * This method only works if this widget is editable, i.e. read-write and
-     * allows you to enable/disable the context menu. It does nothing if invoked
-     * for a none-editable combo-box.
-     *
-     * By default, the context menu is created if this widget is editable.
-     * Call this function with the argument set to false to disable the popup
-     * menu.
-     *
-     * @param showMenu If @c true, show the context menu.
-     * @deprecated since 4.5, use setContextMenuPolicy instead
-     */
-    KCOMPLETION_DEPRECATED_VERSION(4, 5, "Use QWidget::setContextMenuPolicy(Qt::ContextMenuPolicy)")
-    virtual void setContextMenuEnabled(bool showMenu);
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * Returns @c true when the context menu is enabled.
-     * @deprecated since 4.5, use contextMenuPolicy instead
-     */
-    KCOMPLETION_DEPRECATED_VERSION(4, 5, "Use QWidget::contextMenuPolicy()")
-    bool isContextMenuEnabled() const;
-#endif
-
     /**
      * Enables/Disables handling of URL drops. If enabled and the user
      * drops an URL, the decoded URL will be inserted. Otherwise the default
@@ -243,7 +198,7 @@ public:
      *
      * @param enable If @c true, insert decoded URLs
      */
-    void setUrlDropsEnabled(bool enable);  // KF6: remove it and don't create LineEditUrlDropEventFilter by default.
+    void setUrlDropsEnabled(bool enable); // KF6: remove it and don't create LineEditUrlDropEventFilter by default.
 
     /**
      * Returns @c true when decoded URL drops are enabled
@@ -331,51 +286,9 @@ public:
      * This will do nothing if a completion-box already exists.
      *
      * @param box The KCompletionBox to set
-    */
+     */
     void setCompletionBox(KCompletionBox *box);
 
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * This makes the line edit display a grayed-out hinting text as long as
-     * the user didn't enter any text. It is often used as indication about
-     * the purpose of the line edit.
-     * @deprecated since 5.0, use QLineEdit::setPlaceholderText instead.
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use QLineEdit::setPlaceholderText(const QString&)")
-    void setClickMessage(const QString &msg);
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @return the message set with setClickMessage
-     * @deprecated since 5.0, use QLineEdit::placeholderText instead.
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use QLineEdit::placeholderText()")
-    QString clickMessage() const;
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 46)
-    /**
-     * This makes the line edit display an icon on one side of the line edit
-     * which, when clicked, clears the contents of the line edit.
-     * This is useful for such things as location or search bars.
-     *
-     * @deprecated since 5.46 Use QLineEdit::setClearButtonEnabled
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 46, "Use QLineEdit::setClearButtonEnabled(bool)")
-    void setClearButtonShown(bool show);
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 46)
-    /**
-     * @return whether or not the clear button is shown
-     *
-     * @deprecated since 5.46 Use QLineEdit::isClearButtonEnabled
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 46, "Use QLineEdit::isClearButtonEnabled()")
-    bool isClearButtonShown() const;
-#endif
-
     /**
      * @return the size used by the clear button
      * @since 4.1
@@ -392,20 +305,20 @@ public:
     void doCompletion(const QString &text);
 
 Q_SIGNALS:
-
     /**
      * Emitted whenever the completion box is activated.
      */
     void completionBoxActivated(const QString &);
 
     /**
-     * Emitted when the user presses the return key.
+     * Emitted when the user presses the Return or Enter key.
      *
-     *  The argument is the current text. Note that this
-     * signal is @em not emitted if the widget's @c EchoMode is set to
-     * QLineEdit::EchoMode.
+     * The argument is the current text. Note that this signal is @em not emitted
+     * if the widget's @c EchoMode is set to QLineEdit::EchoMode.
+     *
+     * @since 5.81
      */
-    void returnPressed(const QString &);
+    void returnKeyPressed(const QString &text);
 
     /**
      * Emitted when the completion key is pressed.
@@ -421,23 +334,6 @@ Q_SIGNALS:
      */
     void substringCompletion(const QString &);
 
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(4, 5)
-    /**
-     * Emitted when the text is changed NOT by the suggested autocompletion:
-     * either when the user is physically typing keys, or when the text is changed programmatically,
-     * for example, by calling setText().
-     * But not when automatic completion changes the text temporarily.
-     *
-     * @since 4.2.2
-     * @deprecated since 4.5. You probably want to connect to textEdited() instead,
-     * which is emitted whenever the text is actually changed by the user
-     * (by typing or accepting autocompletion), without side effects from
-     * suggested autocompletion either. userTextChanged isn't needed anymore.
-     */
-    KCOMPLETION_DEPRECATED_VERSION(4, 5, "Use QLineEdit::textEdited(const QString&)")
-    QT_MOC_COMPAT void userTextChanged(const QString &);
-#endif
-
     /**
      * Emitted when the text rotation key-bindings are pressed.
      *
@@ -522,24 +418,12 @@ public Q_SLOTS:
      */
     virtual void setText(const QString &);
 
-    /**
-     * @brief set the line edit in password mode.
-     * this change the EchoMode according to KDE preferences.
-     * @param passwordMode true to set in password mode
-     */
-    void setPasswordMode(bool passwordMode = true);
-
-    /**
-     * @return returns true if the lineedit is set to password mode echoing
-     */
-    bool passwordMode() const;
-
 protected Q_SLOTS:
 
     /**
-    * Completes the remaining text with a matching one from
-    * a given list.
-    */
+     * Completes the remaining text with a matching one from
+     * a given list.
+     */
     virtual void makeCompletion(const QString &);
 
     /**
@@ -550,69 +434,68 @@ protected Q_SLOTS:
     void userCancelled(const QString &cancelText);
 
 protected:
-
     /**
      * Reimplemented for internal reasons. API not affected.
      */
     bool event(QEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::resizeEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::resizeEvent().
+     */
     void resizeEvent(QResizeEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::keyPressEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::keyPressEvent().
+     */
     void keyPressEvent(QKeyEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::mousePressEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::mousePressEvent().
+     */
     void mousePressEvent(QMouseEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::mouseReleaseEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::mouseReleaseEvent().
+     */
     void mouseReleaseEvent(QMouseEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QWidget::mouseDoubleClickEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QWidget::mouseDoubleClickEvent().
+     */
     void mouseDoubleClickEvent(QMouseEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::contextMenuEvent().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::contextMenuEvent().
+     */
     void contextMenuEvent(QContextMenuEvent *) override;
 
     /**
-    * Reimplemented for internal reasons. API not affected.
-    *
-    * See QLineEdit::createStandardContextMenu().
-    */
+     * Reimplemented for internal reasons. API not affected.
+     *
+     * See QLineEdit::createStandardContextMenu().
+     */
     QMenu *createStandardContextMenu();
 
     /**
-    * This function simply sets the lineedit text and
-    * highlights the text appropriately if the boolean
-    * value is set to true.
-    *
-    * @param text
-    * @param marked
-    */
+     * This function simply sets the lineedit text and
+     * highlights the text appropriately if the boolean
+     * value is set to true.
+     *
+     * @param text
+     * @param marked
+     */
     virtual void setCompletedText(const QString & /*text*/, bool /*marked*/);
 
     /**
@@ -623,19 +506,13 @@ protected:
 
     /**
      * Whether in current state text should be auto-suggested
-    */
+     */
     bool autoSuggest() const;
 
     void paintEvent(QPaintEvent *ev) override;
 
 private:
     std::unique_ptr<KLineEditPrivate> const d_ptr;
-
-    Q_PRIVATE_SLOT(d_func(), void _k_textChanged(const QString &))
-    Q_PRIVATE_SLOT(d_func(), void _k_completionMenuActivated(QAction *))
-    Q_PRIVATE_SLOT(d_func(), void _k_tripleClickTimeout())
-    Q_PRIVATE_SLOT(d_func(), void _k_restoreSelectionColors())
-    Q_PRIVATE_SLOT(d_func(), void _k_completionBoxTextChanged(const QString &))
 };
 
 #endif
